==> libgnomeprint-2.1.5.tar.gz: libgnomeprint-2.1.5/libgnomeprint/gpa/gpa-reference.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

#ifndef __GPA_REFERENCE_H__
#define __GPA_REFERENCE_H__

/*
 *  gpa-reference.h:
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Authors :
 *    Jose M. Celorio <chema@ximian.com>
 *    Lauris Kaplinski <lauris@ximian.com>
 *
 *  Copyright (C) 2000-2001 Ximian, Inc. and Jose M. Celorio
 *
 */

#include <glib.h>

G_BEGIN_DECLS

#define GPA_TYPE_REFERENCE         (gpa_reference_get_type ())
#define GPA_REFERENCE(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), GPA_TYPE_REFERENCE, GPAReference))
#define GPA_REFERENCE_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k),    GPA_TYPE_REFERENCE, GPAReferenceClass))
#define GPA_IS_REFERENCE(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), GPA_TYPE_REFERENCE))
#define GPA_IS_REFERENCE_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k),    GPA_TYPE_REFERENCE))
#define GPA_REFERENCE_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o),  GPA_TYPE_REFERENCE, GPAReferenceClass))

#define GPA_REFERENCE_REFERENCE(r) ((r) ? GPA_REFERENCE (r)->ref : NULL)

typedef struct _GPAReference      GPAReference;
typedef struct _GPAReferenceClass GPAReferenceClass;

#include "gpa-node-private.h"

struct _GPAReference {
	GPANode node;
	GPANode *ref;
};

struct _GPAReferenceClass {
	GPANodeClass node_class;
	/* FIXME: Either find better name or move signalling to GPANodeClass (Lauris) */
	gboolean (* set_value) (GPAReference *reference, const guchar *value);
};

GType     gpa_reference_get_type (void);

GPANode * gpa_reference_new (GPANode *node);
GPANode * gpa_reference_new_empty (void);
gboolean  gpa_reference_is_empty (GPANode *ref);

gboolean  gpa_reference_set_reference (GPAReference *reference, GPANode *node);

G_END_DECLS

#endif /* __GPA_REFERENCE_H__ */

==> libgnomeprint_2.8.2.orig.tar.gz: libgnomeprint-2.8.2/libgnomeprint/gpa/gpa-reference.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 *  gpa-reference.h:
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Authors :
 *    Jose M. Celorio <chema@ximian.com>
 *    Lauris Kaplinski <lauris@ximian.com>
 *
 *  Copyright (C) 2000-2003 Ximian, Inc.
 *
 */

#ifndef __GPA_REFERENCE_H__
#define __GPA_REFERENCE_H__

#include <glib.h>

G_BEGIN_DECLS

#define GPA_TYPE_REFERENCE         (gpa_reference_get_type ())
#define GPA_REFERENCE(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), GPA_TYPE_REFERENCE, GPAReference))
#define GPA_IS_REFERENCE(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), GPA_TYPE_REFERENCE))

#define GPA_REFERENCE_REFERENCE(r) ((r) ? GPA_REFERENCE (r)->ref : NULL)

typedef struct _GPAReference      GPAReference;
typedef struct _GPAReferenceClass GPAReferenceClass;

#include "gpa-node-private.h"

struct _GPAReference {
	GPANode node;
	GPANode *ref;
};

struct _GPAReferenceClass {
	GPANodeClass node_class;
};

GType     gpa_reference_get_type (void);

GPAReference * gpa_reference_new (GPANode *node, const guchar *id);
GPAReference * gpa_reference_new_emtpy (const guchar *id);
gboolean       gpa_reference_set_reference (GPAReference *reference, GPANode *node);

G_END_DECLS

#endif /* __GPA_REFERENCE_H__ */
